.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`core.inputtransformer2`
=====================================
.. automodule:: IPython.core.inputtransformer2

.. currentmodule:: IPython.core.inputtransformer2

7 Classes
---------

.. autoclass:: PromptStripper
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: TokenTransformBase
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: MagicAssign
  :members:
  :show-inheritance:

.. autoclass:: SystemAssign
  :members:
  :show-inheritance:

.. autoclass:: EscapedCommand
  :members:
  :show-inheritance:

.. autoclass:: HelpEnd
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: TransformerManager
  :members:
  :show-inheritance:

  .. automethod:: __init__

8 Functions
-----------

.. autofunction:: IPython.core.inputtransformer2.leading_empty_lines


.. autofunction:: IPython.core.inputtransformer2.leading_indent


.. autofunction:: IPython.core.inputtransformer2.cell_magic


.. autofunction:: IPython.core.inputtransformer2.find_end_of_continued_line


.. autofunction:: IPython.core.inputtransformer2.assemble_continued_line


.. autofunction:: IPython.core.inputtransformer2.make_tokens_by_line


.. autofunction:: IPython.core.inputtransformer2.show_linewise_tokens


.. autofunction:: IPython.core.inputtransformer2.find_last_indent

